@@ -1,32 +1,32 @@
 #ifndef DEISOTOPER_H
 #define DEISOTOPER_H
 
+#include <stdexcept>
+#include <algorithm>
+#include <iterator>
 #include <vector>
-
-/*
-
-Authors   : Witold Eryk Wolski <wewolski@gmail.com> and Christian Panse <cp@fgcz.ethz.ch>
-
-This code belongs to two projects:
-o http://cran.r-project.org/web/packages/protViz/index.html under GPLv3 
-o https://github.com/wolski/rl under three-clause BSD license
-
-Copyright : Functional Genomics Center Zurich | UZH | ETHZ and  ETH Zurich 2013
-
-*/
-
-#include <math.h>
-#include <stdint.h>
+#include <stack>
+#include <cmath>
 
 #include <iostream>
-#include <vector>
-#include <stdexcept>
-#include <iterator>
-#include <algorithm>
-#include <stack>
 
 #include <base/chemistry/iisotopeenvelope.h>
 
+/*
+    Authors : Witold Eryk Wolski <wewolski@gmail.com> 
+              Christian Panse <cp@fgcz.ethz.ch>
+
+This code belongs to two projects:
+    o http://cran.r-project.org/web/packages/protViz/index.html under GPLv3 
+    o https://github.com/wolski/rl under three-clause BSD license
+
+    Copyright : Functional Genomics Center Zurich | UZH | ETHZ 2013
+
+    $HeadURL: http://fgcz-svn.unizh.ch/repos/fgcz/testing/proteomics/R/protViz/src/base/ms/deisotoper.h $
+    $Id: deisotoper.h 6357 2014-04-16 07:37:03Z cpanse $
+
+
+*/
 
 namespace ralab{
   namespace base{
@@ -34,6 +34,7 @@ namespace ralab{
 
       class Deisotoper {
 
+        std::vector<std::string> warnings;
         std::vector < int > Z_; // charge states
         std::vector<std::vector < double > > isotopPatternMap;
 
@@ -41,11 +42,18 @@ namespace ralab{
         double hydrogenMass_;
         ralab::base::chemistry::IIsotopeEnvelope * ie_;
 
+        struct Peaks{
+            std::vector < double > m;
+            std::vector < double > aggregatedIntensity;
+            std::vector < int > z;
+        };
+
       public:
 
         typedef std::vector< std::vector< std::vector < int > > > ListOfVectors;
         typedef std::vector< std::vector < double > > ListOfDoubleVectors;
 
+
         struct isotopResult {
           ListOfVectors isotopChains;
           ListOfDoubleVectors isotopInnerProducts;
@@ -57,17 +65,38 @@ namespace ralab{
 
           std::vector < std::vector < int > >isotopGroups;
 
+          Peaks peaks;
+
+
           const std::vector < int > & getIsotopPatten(int i) {
             if (isotopPatternIdx[i].size() > 0)
               return isotopPatternIdx[i];
-          }};
+            return isotopPatternIdx[i];
+          }
+        };
 
         isotopResult result_;
 
+	const std::vector<std::string> & getWarnings(){
+		return warnings;
+	}
+
         const std::vector < std::vector < int > >  & getIsotopGroups() {
           return result_.isotopGroups;
         }
 
+        const std::vector < double > & getPeaksMass() {
+          return result_.peaks.m;
+        }
+
+        const std::vector < double > & getPeaksIntensity() {
+          return result_.peaks.aggregatedIntensity;
+        }
+
+        const std::vector < int > & getPeaksCharge() {
+          return result_.peaks.z;
+        }
+
         const ListOfVectors & getIsotopChainResults() {
           return result_.isotopChains;
         }
@@ -80,7 +109,6 @@ namespace ralab{
           return result_.isotopInnerProducts1;
         }
 
-
         // constructor
         Deisotoper(double massError = 0.1 ):massError_(massError), hydrogenMass_(1.008){}
 
@@ -132,9 +160,14 @@ namespace ralab{
             std::vector<int>::iterator it_NN_begin;
             std::vector<int>::iterator it_NN_end;
 
+            int oldGroupIdx=-1;
             // for all isotop groups
             for(std::vector< int >::iterator it = isoptopGroupsIdx.begin(); it !=isoptopGroupsIdx.end(); ++it){
 
+                // std::unique cannot alter the properties of the object containing the range of elements
+                if (*it <= oldGroupIdx) break;
+                oldGroupIdx = *it;
+                
                 // default -1 means no isotop for this charge state
                 std::vector< int > group(Z_.size(), -1);
 
@@ -166,12 +199,11 @@ namespace ralab{
             }
         }
 
-
         template < typename TmassI, typename TinteI >
         void 
         assignIsotopIntensities(TmassI beginMass, TmassI endMass, TinteI beginIntensity){
 
-            double dIntensityL2,  dIntensityInnerProduct;
+            double dIntensityL2,  dIntensityInnerProduct0, dIntensityInnerProduct1;
 
             // for all charge states
             for (std::vector< std::vector< std::vector< int > > >::iterator it_z = result_.isotopChains.begin(); it_z !=  result_.isotopChains.end(); ++it_z){
@@ -191,26 +223,144 @@ namespace ralab{
                     
                     // TODO here we have to find the mono iso peak!!!  
                     // the winner is tbd
-                    dIntensityInnerProduct = 0.0;
-                    dIntensityInnerProduct = inner_product(beginIntensity, (*it_c).begin(), (*it_c).end(), LIsotopeEnvelope.begin(), LIsotopeEnvelope.end(), dIntensityInnerProduct, dIntensityL2);
-                    Lscore.push_back(dIntensityInnerProduct);
+                    dIntensityInnerProduct0 = 0.0;
+                    dIntensityInnerProduct0 = inner_product(beginIntensity, (*it_c).begin(), (*it_c).end(), LIsotopeEnvelope.begin(), LIsotopeEnvelope.end(), dIntensityInnerProduct0, dIntensityL2);
+                    Lscore.push_back(dIntensityInnerProduct0);
 
-                    dIntensityInnerProduct = 0.0;
+                    dIntensityInnerProduct1 = 0.0;
                     std::vector< int > ::iterator it_c_begin_succ = (*it_c).begin();
                     ++it_c_begin_succ;
-                    dIntensityInnerProduct = inner_product(beginIntensity, it_c_begin_succ, (*it_c).end(), LIsotopeEnvelope.begin(), LIsotopeEnvelope.end(), dIntensityInnerProduct, dIntensityL2);
-                    Lscore1.push_back(dIntensityInnerProduct);
+                    dIntensityInnerProduct1 = inner_product(beginIntensity, it_c_begin_succ, (*it_c).end(), LIsotopeEnvelope.begin(), LIsotopeEnvelope.end(), dIntensityInnerProduct1, dIntensityL2);
+                    Lscore1.push_back(dIntensityInnerProduct1);
+
+                    /*
+                    int l0 = std::distance((*it_c).begin(), (*it_c).end());
+                    int l1 = std::distance(it_c_begin_succ, (*it_c).end());
+
+                    if (dIntensityInnerProduct0 > 0.95 || (l1 > 2 && dIntensityInnerProduct1 > 0.95)){
+                        std::cout << z << "\t" << l0 << "\tscore0=" << l0 * dIntensityInnerProduct0 << "\tscore1=" << l1 * dIntensityInnerProduct1 << std::endl;
+                    }
+                    */
+
                 } //  END for all chains
                 result_.isotopInnerProducts.push_back(Lscore);
                 result_.isotopInnerProducts1.push_back(Lscore1);
             } // END for all charge states z
          }
 
-         template < typename TmassI, typename TinteI >
-         void 
-         deisotopPeaklist(TmassI beginMass, TmassI endMass, TinteI beginIntensity){
-         }
+        template < typename TmassI, typename TinteI >
+        void 
+        deisotopPeaklist(TmassI beginMass, TmassI endMass, TinteI beginIntensity){
+            int nMass = std::distance(beginMass, endMass);
 
+            for (int i = 0; i < nMass; i++){   
+                result_.peaks.m.push_back(*(beginMass + i));
+                result_.peaks.aggregatedIntensity.push_back(*(beginIntensity + i));
+                result_.peaks.z.push_back(0);
+            }
+            //for (int i=0; i<nMass;i++)   
+            //   std::cout << result_.peaks.m[i] << "\t" << mark[i] << "\t" << result_.peaks.aggregatedIntensity[i] << std::endl;
+
+             std::vector < int > mark(nMass, 0);
+
+             int groupIdx, chainIdx, zIdx;
+
+            double monoIsotopicMass, monoIsotopicIntensity;  
+            int nPeakCand = -1; 
+            double eps = 0.90;
+
+            // assume that the first peak is the monoisotopic peak
+            int max_zIdx = -1;
+            int max_chainIdx  = -1;
+            int max_peakShift = 0;
+            double max_score = -1.0;
+
+            int peakShift;
+            double score;
+
+            for(std::vector< std::vector< int > >::iterator itGroup=result_.isotopGroups.begin(); itGroup != result_.isotopGroups.end(); ++itGroup){
+                max_score = -1.0; max_zIdx = -1; max_peakShift = 0; 
+                max_chainIdx = -1;
+                groupIdx = std::distance(result_.isotopGroups.begin(), itGroup);
+                
+                // forall charge idx
+                for (std::vector< int >::iterator it_z = (*itGroup).begin(); it_z !=  (*itGroup).end(); ++it_z){
+
+                    chainIdx = *it_z;
+                    zIdx = std::distance((*itGroup).begin(), it_z);
+
+                    if (chainIdx > -1 ){
+                        nPeakCand = std::distance(result_.isotopChains[zIdx][chainIdx].begin(), result_.isotopChains[zIdx][chainIdx].end());
+
+                        if (result_.isotopInnerProducts[zIdx][chainIdx] > result_.isotopInnerProducts1[zIdx][chainIdx] || nPeakCand < 3){
+                            score = result_.isotopInnerProducts[zIdx][chainIdx] * nPeakCand;
+                            peakShift = 0;
+                        } else {
+                            score = result_.isotopInnerProducts1[zIdx][chainIdx] * (nPeakCand - 1); 
+                            peakShift = 1;
+                        }
+
+                        if (score > max_score){
+                            max_score = score;
+                            max_chainIdx = chainIdx;
+                            max_zIdx  = zIdx; 
+                            max_peakShift = peakShift;
+                        }
+                    }
+                }
+
+// monoisotop peak is determined prepare the output
+                nPeakCand = std::distance(result_.isotopChains[max_zIdx][max_chainIdx].begin(), result_.isotopChains[max_zIdx][max_chainIdx].end());
+                if (result_.isotopInnerProducts[max_zIdx][max_chainIdx] > eps || (nPeakCand > 3 && result_.isotopInnerProducts1[max_zIdx][chainIdx] > eps)){
+                    // chose mono isotopic peak
+
+                    int monoIsotopicPeakIdx = *(result_.isotopChains[max_zIdx][max_chainIdx].begin()) + max_peakShift;
+                    monoIsotopicMass=*(beginMass + monoIsotopicPeakIdx);
+                    monoIsotopicIntensity = *(beginIntensity  + monoIsotopicPeakIdx);
+
+		
+		    if (std::distance(result_.isotopChains[max_zIdx][max_chainIdx].begin() , result_.isotopChains[max_zIdx][max_chainIdx].end())< max_peakShift + 2){
+
+				std::ostringstream sWarning;
+                                sWarning << "isotop peak group to small."; 
+				warnings.push_back(sWarning.str());
+
+			} else{
+                    std::vector<int>::iterator it_BeginIsotopPeakGroup = (result_.isotopChains[max_zIdx][max_chainIdx].begin() +  max_peakShift + 1);
+                    std::vector<int>::iterator it_EndIsotopPeakGroup = result_.isotopChains[max_zIdx][max_chainIdx].end();
+		    std::vector<int>::iterator it_chain;
+			
+                    for (it_chain = it_BeginIsotopPeakGroup; it_chain !=  it_EndIsotopPeakGroup; ++it_chain){
+
+                            // peak can only be used once
+                            if (mark[*it_chain] == 0){
+                                monoIsotopicIntensity += *(beginIntensity + *it_chain);
+                                mark[*it_chain] = monoIsotopicPeakIdx;
+                                result_.peaks.aggregatedIntensity[*it_chain] = 0.0;
+                            }
+                            else{
+				std::ostringstream sWarning;
+
+                                sWarning << "Peak " << result_.peaks.m[*it_chain] << "[" \
+<< *it_chain << "] / " << Z_[max_zIdx] << " can only be used once. Already in use with (idx, m, Z, I) = (" \
+<< *it_chain << ", " << result_.peaks.m[mark[*it_chain]] << ", "  << result_.peaks.z[mark[*it_chain]] \
+<< ", " << result_.peaks.aggregatedIntensity[mark[*it_chain]] << ").";
+
+				warnings.push_back(sWarning.str());
+                            }
+                    }
+
+                    if (result_.peaks.m[monoIsotopicPeakIdx] != monoIsotopicMass){
+			warnings.push_back("ERROR: contradiction in monoIsotopicMass");
+		    }
+                    result_.peaks.aggregatedIntensity[monoIsotopicPeakIdx] = monoIsotopicIntensity;
+                    result_.peaks.z[monoIsotopicPeakIdx] = Z_[max_zIdx];
+
+                    it_chain = result_.isotopChains[max_zIdx][max_chainIdx].begin();
+                }
+		}
+            }//foreach group (isotop cluster)
+         }
 
       private:
         template <typename TinteI, class InputIterator1, class T>
@@ -266,7 +416,7 @@ namespace ralab{
 
           if (it != first) {
               Iterator it_pre = it - 1;
-              if (fabs(val - *it_pre) < fabs(val - *it) || it == last) {
+              if (std::fabs(val - *it_pre) < std::fabs(val - *it) || it == last) {
                   return (it_pre);
                 }
             }
@@ -296,7 +446,7 @@ namespace ralab{
               double dQmZ = (*itMz + (hydrogenMass_ /z));
               Iterator itNNmZ = findNearestNeighbor(firstMz, lastMz, dQmZ);
 
-              if (fabs(*itNNmZ - dQmZ) < massError_)
+              if (std::fabs(*itNNmZ - dQmZ) < massError_)
                 G[std::distance(firstMz, itMz)] =
                     std::distance(firstMz, itNNmZ);
             }
